==> haskell-utf8-string-1.0.2-152-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-utf8-string.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 utf8-string
version:              1.0.2
visibility:           public
id:                   utf8-string-1.0.2-AQMRv3gsvE14uh4nlO1egX
key:                  utf8-string-1.0.2-AQMRv3gsvE14uh4nlO1egX
license:              BSD-3-Clause
maintainer:           emertens@galois.com
author:               Eric Mertens
homepage:             https://github.com/glguy/utf8-string/
synopsis:             Support for reading and writing UTF8 Strings
description:
    A UTF8 layer for Strings. The utf8-string
    package provides operations for encoding UTF8
    strings to Word8 lists and back, and for reading and
    writing UTF8 without truncation.

category:             Codec
abi:                  42c2b0a51b490a31434f20f0d20a8a95
exposed:              True
exposed-modules:
    Codec.Binary.UTF8.Generic Codec.Binary.UTF8.String
    Data.ByteString.Lazy.UTF8 Data.ByteString.UTF8 Data.String.UTF8

import-dirs:          /usr/lib/ghc-9.2.8/site-local/utf8-string-1.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/utf8-string-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-utf8-string
hs-libraries:         HSutf8-string-1.0.2-AQMRv3gsvE14uh4nlO1egX
depends:              base-4.16.4.0 bytestring-0.11.4.0
haddock-interfaces:   /usr/share/doc/haskell-utf8-string/html/utf8-string.haddock
haddock-html:         /usr/share/doc/haskell-utf8-string/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-utf8-string-1.0.2-185.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-utf8-string.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 utf8-string
version:              1.0.2
visibility:           public
id:                   utf8-string-1.0.2-FnO1h94XkEn7naEuvLflUO
key:                  utf8-string-1.0.2-FnO1h94XkEn7naEuvLflUO
license:              BSD-3-Clause
maintainer:           emertens@galois.com
author:               Eric Mertens
homepage:             https://github.com/glguy/utf8-string/
synopsis:             Support for reading and writing UTF8 Strings
description:
    A UTF8 layer for Strings. The utf8-string
    package provides operations for encoding UTF8
    strings to Word8 lists and back, and for reading and
    writing UTF8 without truncation.

category:             Codec
abi:                  9eea3d6f5c9af43e73dfacdfe4177a95
exposed:              True
exposed-modules:
    Codec.Binary.UTF8.Generic Codec.Binary.UTF8.String
    Data.ByteString.Lazy.UTF8 Data.ByteString.UTF8 Data.String.UTF8

import-dirs:          /usr/lib/ghc-9.4.8/site-local/utf8-string-1.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/utf8-string-1.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/utf8-string-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-utf8-string
hs-libraries:         HSutf8-string-1.0.2-FnO1h94XkEn7naEuvLflUO
depends:              base-4.17.2.1 bytestring-0.11.5.3
haddock-interfaces:   /usr/share/doc/haskell-utf8-string/html/utf8-string.haddock
haddock-html:         /usr/share/doc/haskell-utf8-string/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
